@@ -1,5 +1,6 @@
 from pathlib import Path
 import platform
+from turtle import back
 
 import PySimpleGUI as sg
 
@@ -34,10 +35,10 @@ def textbox(text, title):
     else:
         size = (800, 400)
     layout = [
-        [sg.Multiline(text, font=('Courier', 10), size_px=size)],
+        [sg.Multiline(text, font=('Courier', 10), expand_x=True, expand_y=True)],
         [sg.B('Done')]
         ]
-    window = sg.Window(title, layout, icon=get_icon())
+    window = sg.Window(title, layout, icon=get_icon(), resizable=True, size=size)
     window.read()
     window.close()
 
@@ -48,4 +49,15 @@ def listbox(message: str, items: list, title: str):
     window = sg.Window(title, layout, icon=get_icon())
     window.read()
     window.close()
+
+def mac_win_cmd(text: str, title: str, mac_cmd: str, win_cmd: str):
+    layout = [
+        [sg.T(text)],
+        [sg.T('MacOS:', size=(10, 1)), sg.Input(mac_cmd, readonly=True, disabled_readonly_background_color='#000000', disabled_readonly_text_color='#ffffff')],
+        [sg.T('Windows:', size=(10, 1)), sg.Input(win_cmd, readonly=True, disabled_readonly_background_color='#000000', disabled_readonly_text_color='#ffffff')],
+        [sg.Stretch(), sg.Button('Ok', size=(5, 1)), sg.Stretch()],
+    ]
+    window = sg.Window(title, layout, icon=get_icon())
+    window.read()
+    window.close()
     
\ No newline at end of file
